import React, { createContext, useEffect, useState } from 'react';
import { ErrorOption } from 'react-hook-form';
import { FieldLabelProps } from '@digigov/form/Field/types';
import { List, ListItem } from '@digigov/ui/content/List';
import { ErrorSummary } from '@digigov/ui/feedback/ErrorSummary';
import { useTranslation } from '@digigov/ui/i18n';
import { Link } from '@digigov/ui/navigation/Link';
import { Heading } from '@digigov/ui/typography/Heading';
import { Base } from '@digigov/ui/utils/Base';
import { Breakpoints } from '@digigov/ui/utils/hooks/useScreen';
interface ErrorGroupContextType {
  setError: (
    name?: string,
    label?: FieldLabelProps,
    error?: ErrorOption
  ) => void;
}
export const ErrorGroupContext = createContext<ErrorGroupContextType | null>(
  null
);

export interface ErrorGroupProps {
  children: React.ReactNode;
  screenSize?: Breakpoints | undefined;
  fieldOrder?: any[];
}

export const ErrorGroup: React.FC<ErrorGroupProps> = ({
  children,
  screenSize,
  fieldOrder,
}) => {
  const [errors, setErrors] = useState<ErrorOption>({});
  const { t } = useTranslation();
  const setError = (name, label, error) => {
    if (errors[name] !== error && errors[name]?.message !== error?.message) {
      if (!error?.message) {
        const updatedErrors = { ...errors };
        delete updatedErrors[name];
        setErrors(updatedErrors);
      } else {
        setErrors({
          ...errors,
          [name]: {
            ...error,
            label: label.primary,
          },
        });
      }
    }
  };

  useEffect(() => {
    setErrors({});
  }, [screenSize]);
  return (
    <ErrorGroupContext.Provider value={{ setError }}>
      {Object.keys(errors).length !== 0 && (
        <ErrorSummary variant="error-group">
          <Heading size="sm">
            Τα παρακάτω πεδία της φόρμας ειναι λάθος.{' '}
          </Heading>
          <List listStyle="bullet">
            {(fieldOrder || Object.keys(errors).reverse())
              .filter((fieldName) => errors[fieldName])
              .map((fieldName, index) => {
                return (
                  <ListItem key={index} id={`${fieldName}-error`}>
                    <Base as="b">{t(errors[fieldName]?.label)}:</Base>{' '}
                    <Link href={`#${fieldName}`}>
                      {t(errors[fieldName]?.message)}
                    </Link>
                  </ListItem>
                );
              })}
          </List>
        </ErrorSummary>
      )}
      {children}
    </ErrorGroupContext.Provider>
  );
};

export default ErrorGroup;
