import React, { useContext, useEffect } from 'react';
import { Controller } from 'react-hook-form';
import { ErrorGroupContext } from '@digigov/form/Field/ErrorGroup';
import FieldBaseContainer from '@digigov/form/Field/FieldBaseContainer';
import { FieldBaseProps } from '@digigov/form/Field/types';

export const FieldBase: React.FC<FieldBaseProps> = ({
  required,
  name,
  component: Component,
  wrapper,
  control,
  type,
  controlled = false,
  enabled = true,
  editable,
  defaultValue,
  label,
  extra = {},
  layout,
  error,
  register,
  ...componentProps
}) => {
  const errorGroupContext = useContext(ErrorGroupContext);

  useEffect(() => {
    if (errorGroupContext) {
      errorGroupContext.setError(name, label, error);
    }
  }, [error, name, errorGroupContext?.setError]);

  if (!enabled) {
    return null;
  }

  if (controlled) {
    return (
      <FieldBaseContainer
        label={label}
        layout={layout}
        error={errorGroupContext ? undefined : error}
        hasError={!!error}
        wrapper={wrapper}
        name={name}
      >
        <Controller
          control={control}
          name={name}
          render={({ field }) => {
            return (
              <Component
                {...field}
                control={control}
                ref={undefined}
                defaultValue={defaultValue}
                extra={extra}
                error={!!error}
                type={type}
                aria-required={!!required}
                aria-describedby={error && `${name}-error`}
                required={required}
                disabled={editable === false}
                {...componentProps}
              />
            );
          }}
        />
      </FieldBaseContainer>
    );
  }

  return (
    <FieldBaseContainer
      label={label}
      layout={layout}
      error={errorGroupContext ? undefined : error}
      hasError={!!error}
      wrapper={wrapper}
      name={name}
    >
      {Component?.render ? (
        <Component
          {...register(name)}
          control={control}
          error={!!error}
          extra={extra}
          type={type}
          aria-required={!!required}
          aria-describedby={error && `${name}-error`}
          required={required}
          disabled={editable === false}
          {...componentProps}
        />
      ) : (
        <Component
          {...register(name)}
          register={register}
          control={control}
          error={!!error}
          extra={extra}
          type={type}
          aria-required={!!required}
          aria-describedby={error && `${name}-error`}
          required={required}
          disabled={editable === false}
          ref={undefined}
          {...componentProps}
        />
      )}
    </FieldBaseContainer>
  );
};
