import React from 'react';
import { FieldContainerProps } from '@digigov/form/Field/types';
import Label from '@digigov/form/inputs/Label';
import { ErrorMessage } from '@digigov/react-core/ErrorMessage';
import FieldContainer from '@digigov/react-core/FieldContainer';
import CoreFieldset from '@digigov/react-core/Fieldset';
import FieldsetLegend from '@digigov/react-core/FieldsetLegend';
import LabelContainer from '@digigov/react-core/LabelContainer';
import { useTranslation } from '@digigov/ui/i18n';
import { Hint } from '@digigov/ui/typography/Hint';

export const FieldBaseContainer: React.FC<FieldContainerProps> = ({
  name,
  wrapper,
  label,
  children,
  error,
  hasError,
  layout,
}) => {
  const { t } = useTranslation();
  const errorMessage = error?.message.key
    ? error.message.key
    : error?.message || '';
  const errorContext = error?.message.context || {};
  if (wrapper === 'fieldset') {
    return (
      <FieldContainer error={hasError} {...layout}>
        <CoreFieldset>
          <FieldsetLegend size="sm">{label && label.primary}</FieldsetLegend>
          {label && label.secondary && <Hint>{t(label.secondary)}</Hint>}
          {error && (
            <ErrorMessage id={`${name}-error`}>
              {t(errorMessage, errorContext)}
            </ErrorMessage>
          )}
          {children}
        </CoreFieldset>
      </FieldContainer>
    );
  } else {
    return (
      <FieldContainer error={hasError} {...layout}>
        <LabelContainer>
          {label && <Label label={label} />}
          {error && (
            <ErrorMessage id={`${name}-error`}>
              {t(errorMessage, errorContext)}
            </ErrorMessage>
          )}
          {children}
        </LabelContainer>
      </FieldContainer>
    );
  }
};

export default FieldBaseContainer;
