import React from 'react';
import { useWatch } from 'react-hook-form';
import { FieldBase } from '@digigov/form/Field/FieldBase';
import {
  ChildFieldMemoProps,
  FieldConditionalProps,
} from '@digigov/form/Field/types';
import { evaluateFieldWithConditions } from '@digigov/form/Field/utils/evaluateFieldWithConditions';

const ChildFieldMemo = React.memo(
  function ChildField({
    dependencies,
    field,
    control,
    reset,
    register,
    error,
    Field,
  }: ChildFieldMemoProps) {
    const newField = evaluateFieldWithConditions(
      field,
      dependencies as FormData
    );
    return (
      <FieldBase
        {...newField}
        Field={Field}
        name={newField.key}
        reset={reset}
        control={control}
        register={register}
        error={error}
      />
    );
  },
  (prev, next) => {
    if (!prev || !prev.dependencies) {
      return false;
    }
    if (prev.error !== next.error) {
      return false;
    }
    for (const dep in next.dependencies) {
      if (next.dependencies[dep] !== prev.dependencies[dep]) {
        return false;
      }
    }
    return true;
  }
);

export const FieldConditional: React.FC<FieldConditionalProps> = ({
  control,
  field,
  register,
  reset,
  error,
  Field,
}) => {
  const dependencyKeys = Object.keys(field.condition);
  const dependencyValues = useWatch({
    name: dependencyKeys,
    control,
  });
  const variables = dependencyKeys.reduce(
    (data, fieldKey, index) => ({
      ...data,
      [fieldKey]: dependencyValues[index],
    }),
    {}
  );
  return (
    <ChildFieldMemo
      dependencies={variables}
      field={field}
      control={control}
      register={register}
      reset={reset}
      error={error}
      Field={Field}
    />
  );
};

export default FieldConditional;
