import React, { useMemo } from 'react';
import { FieldBase } from '@digigov/form/Field/FieldBase';
import FieldConditional from '@digigov/form/Field/FieldConditional';
import {
  FieldWithCondition,
  CalculatedField,
  FieldProps,
} from '@digigov/form/Field/types';
import {
  FIELD_COMPONENTS,
  ALTERNATIVE_COMPONENTS,
} from '@digigov/form/Field/utils';
import { calculateField } from '@digigov/form/Field/utils/calculateField';
import { useField } from '@digigov/form/Field/utils/useField';
import FieldArray from '@digigov/form/FieldArray';
import Multiplicity from '@digigov/form/MultiplicityField';
export const Field: React.FC<FieldProps> = ({
  name,
  disabled,
  children,
  ...customField
}) => {
  const {
    field,
    control,
    register,
    reset,
    error,
    componentRegistry,
    formState,
    setValue,
    getValues,
    unregister,
    trigger,
    clearErrors,
  } = useField(name, customField?.type ? customField : null);
  const calculatedField: CalculatedField = useMemo(
    () =>
      calculateField(
        children,
        field,
        {
          ...FIELD_COMPONENTS,
          ...componentRegistry,
        },
        ALTERNATIVE_COMPONENTS
      ),
    [field]
  );

  if (calculatedField.condition) {
    return (
      <FieldConditional
        control={control}
        reset={reset}
        register={register}
        field={calculatedField as FieldWithCondition}
        error={error}
        Field={Field}
      />
    );
  }
  if (calculatedField.type === 'array' && !calculatedField.multiplicity) {
    calculatedField.name = name;
    return (
      <FieldArray
        control={control}
        register={register}
        error={error}
        formState={formState}
        Field={Field}
        {...calculatedField}
      />
    );
  }
  if (
    calculatedField.type === 'array' &&
    calculatedField.multiplicity === true
  ) {
    calculatedField.name = name;
    return (
      <Multiplicity
        control={control}
        register={register}
        trigger={trigger}
        clearErrors={clearErrors}
        error={error}
        formState={formState}
        setValue={setValue}
        getValues={getValues}
        unregister={unregister}
        Field={Field}
        {...calculatedField}
      />
    );
  }
  return (
    <FieldBase
      {...calculatedField}
      name={name}
      disabled={disabled}
      control={control}
      register={register}
      reset={reset}
      error={error}
      Field={Field}
    />
  );
};

export default Field;
