import React from 'react';
import { ErrorOption, UseFormReturn, UseFormProps } from 'react-hook-form';
import { ValidatorSchema } from '@digigov/form/validators/types';
import { GridProps } from '@digigov/ui/layouts/Grid';

export interface FieldLabelProps {
  primary?: string;
  secondary?: string;
}

export interface FieldSpec {
  key: string; // !TODO rename key to name;
  type?:
    | 'int'
    | 'string'
    | 'text'
    | 'boolean'
    | 'email'
    | 'uuid4'
    | 'choice:multiple'
    | 'choice:single'
    | 'mobile_phone'
    | 'date'
    | 'otp'
    | 'afm'
    | 'iban'
    | 'file'
    | 'image'
    | 'postal_code'
    | 'phone_number'
    | 'array'
    | 'object';
  trim?: boolean;
  component?: any;
  autoComplete?: string;
  maxLength?: number;
  condition?: Record<string, FieldCondition>;
  controlled?: boolean;
  label?: FieldLabelProps;
  extra?: Record<string, any>;
  editable?: boolean;
  required?: boolean;
  enabled?: boolean;
  disabled?: boolean;
  layout?: Record<
    string,
    | GridProps['xs']
    | GridProps['sm']
    | GridProps['md']
    | GridProps['lg']
    | GridProps['xl']
  >;
  validators?: ValidatorSchema[];
  wrapper?: 'label' | 'fieldset';
  maxWidth?: string;
  maxHeight?: string;
  width?: string;
}

export interface FieldCondition {
  is: string | string[] | number | number[] | boolean | boolean[];
  then?: Partial<FieldSpec>;
  else?: Partial<FieldSpec>;
}
export interface ChildFieldMemoProps extends FieldConditionalProps {
  dependencies: FormData;
}
export type FormData = UseFormProps['defaultValues'];

export interface FieldWithCondition extends Omit<CalculatedField, 'condition'> {
  condition: Record<string, FieldCondition>;
}

export interface FieldConditionalProps {
  field: FieldWithCondition;
  control: UseFormReturn['control'];
  register: UseFormReturn['register'];
  reset: UseFormReturn['reset'];
  error?: ErrorOption;
  Field: React.FC<FieldProps>;
}

export interface FieldComponentItem {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  component: any;
  controlled?: boolean;
  wrapper?: FieldSpec['wrapper'];
}

export interface FieldContainerProps {
  name?: FieldSpec['key'];
  layout?: FieldSpec['layout'];
  label?: FieldSpec['label'];
  error?: ErrorOption | Record<string, any>;
  hasError?: boolean;
  children?: React.ReactNode;
  wrapper?: FieldSpec['wrapper'];
}

export type FieldComponentRegistry = Record<string, FieldComponentItem>;

export type OmittedFieldSpec = Omit<FieldSpec, 'component'>;

export type UnknownValue = never | never[];

export interface ControlledFieldProps {
  type?: string;
  value: UnknownValue;
  onChange: (v: UnknownValue) => void;
  defaultValue?: UnknownValue;
  onBlur?: (e: Event) => void;
  extra?: never;
  error?: boolean;
  name?: string;
  disabled?: boolean;
  Field: React.FC<FieldProps>;
}

export interface UncontrolledFieldProps {
  name: string;
  register: FieldBaseProps['register'];
  control?: FieldBaseProps['control'];
  error?: boolean;
  extra?: Record<string, never>;
  type?: string;
  disabled?: boolean;
  Field: React.FC<FieldProps>;
}

export interface CalculatedField extends OmittedFieldSpec {
  name: string;
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  component: any;
  defaultValue?: never;
  error?: ErrorOption;
  wrapper?: FieldComponentItem['wrapper'];
  multiplicity?: boolean;
}

export interface FieldBaseProps extends CalculatedField {
  control: UseFormReturn['control'];
  register: UseFormReturn['register'];
  reset: UseFormReturn['reset'];
  Field: React.FC<FieldProps>;
}

export interface FieldProps extends FieldSpec {
  name: string;
  children?: React.ReactNode;
}

export interface UseFieldProps {
  field: FieldSpec;
  control: FieldBaseProps['control'];
  register: FieldBaseProps['register'];
  reset: FieldBaseProps['reset'];
  watch: UseFormReturn['watch'];
  formState: UseFormReturn['formState'];
  getFieldState: UseFormReturn['getFieldState'];
  setValue: UseFormReturn['setValue'];
  getValues: UseFormReturn['getValues'];
  unregister: UseFormReturn['unregister'];
  trigger: UseFormReturn['trigger'];
  clearErrors: UseFormReturn['clearErrors'];
  error?: ErrorOption;
  componentRegistry?: FieldComponentRegistry;
}
