import {
  FieldProps,
  FieldSpec,
  FieldComponentRegistry,
  CalculatedField,
} from '@digigov/form/Field/types';

export function calculateField(
  children: FieldProps['children'],
  field: FieldSpec,
  fieldComponentRegistry: FieldComponentRegistry,
  alternativeComponents: FieldComponentRegistry
): CalculatedField {
  const calculatedField = { ...field };
  if (children) {
    calculatedField.component = children;
    calculatedField.controlled = true;
  } else if (typeof field.component === 'function') {
    // leave as is
  } else if (!field.component && !field.type) {
    calculatedField.component = fieldComponentRegistry.string.component;
    calculatedField.controlled =
      fieldComponentRegistry.string?.controlled || false;
  } else if (
    typeof field?.extra?.component === 'string' &&
    alternativeComponents[field.extra.component]
  ) {
    calculatedField.controlled =
      alternativeComponents[field.extra.component]?.controlled || false;
    calculatedField.component =
      alternativeComponents[field.extra.component].component;
    calculatedField.wrapper =
      alternativeComponents[field.extra.component].wrapper;
  } else if (
    !field.component &&
    field.type &&
    fieldComponentRegistry[field.type]
  ) {
    calculatedField.component = fieldComponentRegistry[field.type].component;
    calculatedField.wrapper = fieldComponentRegistry[field.type].wrapper;
    calculatedField.controlled =
      fieldComponentRegistry[field.type]?.controlled || false;
  } else {
    calculatedField.component = fieldComponentRegistry.string.component;
    calculatedField.controlled =
      fieldComponentRegistry.string?.controlled || false;
  }
  return calculatedField as CalculatedField;
}
