import { useContext, useMemo } from 'react';
import { FieldSpec, UseFieldProps } from '@digigov/form/Field/types';
import { FormContext } from '@digigov/form/FormContext';

export const useField = (
  name: string,
  customField: FieldSpec | null
): UseFieldProps => {
  const {
    fieldsMap,
    control,
    register,
    reset,
    trigger,
    clearErrors,
    errors,
    registerField,
    watch,
    componentRegistry,
    getFieldState,
    setValue,
    getValues,
    unregister,
    formState,
  } = useContext(FormContext);

  if (!registerField) {
    throw new Error(`
      You can't use the Field component without wrapping it in FormBuilder.
      https://devs.pages.grnet.gr/digigov/digigov-sdk/sdk-docs/forms/create-simple-form/
    `);
  }

  useMemo(
    () => customField?.type && registerField({ ...customField, key: name }),
    [customField, name, registerField]
  );
  return {
    field: customField || fieldsMap[name],
    control,
    register,
    reset,
    trigger,
    watch,
    componentRegistry,
    getFieldState,
    setValue,
    clearErrors,
    getValues,
    unregister,
    formState,
    error: errors[name],
  };
};
