import React from 'react';
import { ErrorOption, useFieldArray, UseFormReturn } from 'react-hook-form';
import { FieldBaseContainer } from '@digigov/form/Field/FieldBaseContainer';
import { FieldProps } from '@digigov/form/Field/types';
import { FieldObject } from '@digigov/form/FieldObject';
import { FieldsetLabel, Fieldset } from '@digigov/form/Fieldset';
import { Card } from '@digigov/ui/content/Card';
import { Button } from '@digigov/ui/form/Button';
import { Hint } from '@digigov/ui/typography/Hint';

export interface FieldArrayProps extends FieldProps {
  control: UseFormReturn['control'];
  register: UseFormReturn['register'];
  formState: UseFormReturn['formState'];
  error?: ErrorOption;
  Field: React.FC<FieldProps>;
}
export const FieldArray: React.FC<FieldArrayProps> = ({
  name,
  register,
  control,
  formState,
  error,
  layout,
  label,
  Field,
  ...customField
}) => {
  const { fields, append, remove } = useFieldArray({
    control,
    name,
  });

  return (
    <FieldBaseContainer
      label={label}
      layout={layout}
      error={
        formState.isSubmitted &&
        !formState.isSubmitting &&
        error?.message &&
        error
          ? error
          : undefined
      }
      hasError={formState.isSubmitted && !formState.isSubmitting && !!error}
      wrapper="fieldset"
      name={name}
    >
      {fields.length === 0 && (
        <Hint>{customField.extra?.label.object?.nothing_added}</Hint>
      )}
      {fields.map((field, index) => (
        <Card variant="border" key={field.id}>
          <Fieldset>
            <FieldsetLabel>
              {customField.extra?.label.object.title} {index + 1}
            </FieldsetLabel>
            <FieldObject
              name={`${name}.${index}`}
              error={Array.isArray(error) && error[index]}
              formState={formState}
              register={register}
              control={control}
              {...customField.extra?.of}
              Field={Field}
            />
            <Button
              name={`${name}-object-remove`}
              type="button"
              color="warning"
              onClick={() => remove(index)}
            >
              {customField.extra?.label.object?.delete}
            </Button>
          </Fieldset>
        </Card>
      ))}

      <Button
        type="button"
        name={`${name}-add-object`}
        color="secondary"
        onClick={(ev) => {
          ev.preventDefault();
          append({});
        }}
      >
        {customField.extra?.label.object?.add}
      </Button>
    </FieldBaseContainer>
  );
};

export default FieldArray;
