import React, { useMemo } from 'react';
import { ErrorOption, UseFormReturn } from 'react-hook-form';
import { FieldBase } from '@digigov/form/Field/FieldBase';
import { CalculatedField, FieldProps } from '@digigov/form/Field/types';
import {
  FIELD_COMPONENTS,
  ALTERNATIVE_COMPONENTS,
} from '@digigov/form/Field/utils';
import { calculateField } from '@digigov/form/Field/utils/calculateField';
import { Fieldset, FieldsetCaption } from '@digigov/form/Fieldset';
import { FieldSpec } from '@digigov/form/types';
import { FieldsetLegend } from '@digigov/ui/form/FieldContainer';
import { useTranslation } from '@digigov/ui/i18n';

export interface FieldObjectProps extends Omit<FieldProps, 'key'> {
  control: UseFormReturn['control'];
  register: UseFormReturn['register'];
  reset: UseFormReturn['reset'];
  formState: UseFormReturn['formState'];
  error?: ErrorOption;
  Field: React.FC<FieldProps>;
}

export const FieldObject: React.FC<FieldObjectProps> = ({
  name,
  label,
  extra,
  control,
  register,
  reset,
  formState,
  error,
  Field,
}) => {
  const { t } = useTranslation();

  return (
    <Fieldset>
      {label?.primary && (
        <FieldsetLegend size="sm">{t(label.primary)}</FieldsetLegend>
      )}
      {label?.secondary && (
        <FieldsetCaption>{t(label.secondary)}</FieldsetCaption>
      )}
      {extra?.fields.map((field) => (
        <FieldObjectItem
          key={`${name}.${field.key}`}
          name={`${name}.${field.key}`}
          control={control}
          register={register}
          reset={reset}
          field={field}
          error={error && error[field.key]}
          formState={formState}
          Field={Field}
        />
      ))}
    </Fieldset>
  );
};

export interface FieldObjectItemProps {
  name: string;
  field: FieldSpec;
  control: UseFormReturn['control'];
  register: UseFormReturn['register'];
  reset: UseFormReturn['reset'];
  formState: UseFormReturn['formState'];
  error?: ErrorOption;
  children?: React.ReactNode;
  Field: React.FC<FieldProps>;
}

const FieldObjectItem: React.FC<FieldObjectItemProps> = ({
  name,
  children,
  field,
  error,
  control,
  formState,
  reset,
  register,
  Field,
}) => {
  const calculatedField: CalculatedField = useMemo(
    () =>
      calculateField(children, field, FIELD_COMPONENTS, ALTERNATIVE_COMPONENTS),
    [field]
  );

  const customError = error ? error : formState?.errors[name];
  return (
    <FieldBase
      {...calculatedField}
      name={name}
      Field={Field}
      control={control}
      reset={reset}
      register={register}
      error={customError}
    />
  );
};

export default FieldObject;
