import React, { useContext, useMemo } from 'react';
import Field from '@digigov/form/Field';
import {
  Fieldset,
  FieldsetLabel,
  FieldsetCaption,
  FieldsetBody,
} from '@digigov/form/Fieldset/';
import { FormContext } from '@digigov/form/FormContext';
import { FieldsetSpec } from '@digigov/form/types';
import { useTranslation } from '@digigov/ui/i18n';

export const FieldsetWithContext: React.FC<{ name: string }> = ({ name }) => {
  const { label, body, fields } = useFieldset(name);
  const { t } = useTranslation();
  return useMemo(
    () => (
      <Fieldset>
        {label?.primary && <FieldsetLabel>{t(label.primary)}</FieldsetLabel>}
        {label?.secondary && (
          <FieldsetCaption>{t(label.secondary)}</FieldsetCaption>
        )}
        {body && <FieldsetBody>{body}</FieldsetBody>}
        {fields.map((field) => (
          <Field key={field} name={field} />
        ))}
      </Fieldset>
    ),
    [label?.primary, label?.secondary, body, fields]
  );
};

const useFieldset = (name: string): FieldsetSpec => {
  const { fieldsetsMap } = useContext(FormContext);
  if (fieldsetsMap && fieldsetsMap[name]) {
    return useMemo(() => fieldsetsMap[name], [name]);
  } else {
    if (!fieldsetsMap) throw new Error(`Fieldsets is not defined`);
    throw new Error(`No fieldset with name ${name} found`);
  }
};
