import React from 'react';
import FormBuilder, { Field, FieldSpec } from '@digigov/form';
import { Button } from '@digigov/ui/form/Button';

const fields = [
  {
    key: 'string',
    type: 'string',
    label: {
      primary: 'Πεδίο κειμένου',
      secondary:
        'Το multiplicity field είναι ένα πεδίο οπότε φαίνεται και είναι μέρος της φόρμας',
    },
  },
  {
    key: 'multiplicity',
    type: 'array',
    multiplicity: true,
    label: {
      primary: 'Συνυπογράφοντες',
      secondary: 'Οι συνυπογράφοντες είναι άνθρωποι σαν και εμάς',
    },
    extra: {
      border: true,
      label: {
        object: {
          title: 'Συνυπογράφοντας',
          title_added: 'Οι συνυπογράφοντες που έχετε προσθέσει',
          add: 'Προσθήκη',
          delete: 'Αφαίρεση συνυπογράφοντος',
        },
        question: {
          title: 'Θέλετε να προσθέσετε επιπλέον συνυπογράφοντες;',
          objectLabel: {
            primary: 'Προσθήκη νέου συνυπογράφοντα',
            secondary: 'Συμπληρώστε τα στοιχεία και μετά πατήστε «Προσθήκη»',
          },
          yes: 'Ναι',
          no: 'Όχι',
        },
      },
      of: {
        type: 'object',
        label: {
          primary: 'Στοιχεία συνυπογράφοντα',
          secondary: 'Δείτε και αλλάξτε τα στοιχεία του συνυπογράφοντα',
        },
        extra: {
          fields: [
            {
              key: 'afm',
              type: 'afm',
              required: true,
              label: { primary: 'ΑΦΜ' },
            },
            {
              key: 'firstName',
              required: true,
              type: 'string',
              label: {
                primary: 'Όνομα',
              },
            },
            {
              key: 'lastName',
              required: true,
              type: 'string',
              label: {
                primary: 'Επώνυμο',
              },
            },
          ],
        },
      },
    },
  },
  {
    key: 'phonenumber',
    type: 'phone_number',
    required: true,
    label: {
      primary: 'Σταθερό τηλέφωνο',
      secondary: 'Συμπληρώστε τον αριθμό τηλεφώνου σας',
    },
  },
] as FieldSpec[];

export const Default = () => (
  <FormBuilder
    onSubmit={(data) => {
      console.log(data);
    }}
  >
    <Field name="string" {...fields[0]} />
    <Field name="multiplicity" {...fields[1]} />
    <Field name="phonenumber" {...fields[2]} />
    <Button type="submit">Συνέχεια</Button>
  </FormBuilder>
);
