import React from 'react';
import FormBuilder, { Field, FieldSpec } from '@digigov/form';
import { Button } from '@digigov/ui/form/Button';

const fields = [
  {
    key: 'string',
    type: 'string',
    label: {
      primary: 'Πεδίο κειμένου',
      secondary:
        'Το multiplicity field είναι ένα πεδίο οπότε φαίνεται και είναι μέρος της φόρμας',
    },
  },
  {
    key: 'multiplicity',
    type: 'array',
    multiplicity: true,
    label: {
      primary: 'Εξαρτώμενα μέλη',
      secondary:
        'Τα εξαρτώμενα μέλη είναι φυσικά πρόσωπα που υπάγονται στη φορολογική σας δήλωση',
    },
    extra: {
      label: {
        object: {
          title: 'Εξαρτώμενο μέλος',
          add: 'Προσθήκη',
          delete: 'Αφαίρεση μέλους',
        },
        question: {
          title: 'Θέλετε να προσθέσετε εξαρτώμενα μέλη;',
          yes: 'Ναι',
          no: 'Όχι',
        },
      },
      min: 2,
      max: 3,
      of: {
        type: 'object',
        label: {
          primary: 'Στοιχεία εξαρτώμενου μέλους',
          secondary:
            'Συμπληρώστε τα στοιχεία παρακάτω και μετά πατήστε το κουμπί «Προσθήκη»',
        },
        extra: {
          fields: [
            {
              key: 'firstName',
              required: true,
              type: 'string',
              label: {
                primary: 'Όνομα',
              },
            },
            {
              key: 'lastName',
              required: true,
              type: 'string',
              label: {
                primary: 'Επώνυμο',
              },
            },
            {
              key: 'dob',
              required: true,
              type: 'date',
              label: {
                primary: 'Ημερομηνία γέννησης',
              },
              extra: {
                max: 'now',
              },
            },
          ],
        },
      },
    },
  },
  {
    key: 'phonenumber',
    type: 'phone_number',
    required: true,
    label: {
      primary: 'Σταθερό τηλέφωνο',
      secondary: 'Συμπληρώστε τον αριθμό τηλεφώνου σας',
    },
  },
] as FieldSpec[];

export const WithMinAndMaxLength = () => (
  <FormBuilder
    onSubmit={(data) => {
      console.log(data);
    }}
  >
    <Field name="string" {...fields[0]} />
    <Field name="multiplicity" {...fields[1]} />
    <Field name="phonenumber" {...fields[2]} />
    <Button type="submit">Συνέχεια</Button>
  </FormBuilder>
);
