import React, { useState } from 'react';
import { useFieldArray, UseFormReturn } from 'react-hook-form';
import { FieldBaseContainer } from '@digigov/form/Field/FieldBaseContainer';
import { FieldObject } from '@digigov/form/FieldObject';
import { AddObjects } from '@digigov/form/MultiplicityField/add-objects';
import {
  MultiplicityProps,
  StashedObject,
} from '@digigov/form/MultiplicityField/types';
import {
  Card,
  CardHeading,
  CardContent,
  CardAction,
} from '@digigov/ui/content/Card';
import { Button } from '@digigov/ui/form/Button';
import { Heading } from '@digigov/ui/typography/Heading';

// epeidh einai forwardRef to ref mas to dinei xwrista apo ta props
export const Multiplicity: React.FC<MultiplicityProps> = ({
  extra,
  name,
  control,
  error,
  register,
  trigger,
  clearErrors,
  formState,
  label,
  layout,
  setValue,
  getValues,
  unregister,
  Field,
}) => {
  const { fields, append, remove } = useFieldArray({
    control,
    name,
  });
  const [stashedObjects, setStashedObjects] = useState<StashedObject[]>([]);
  const handleStash = (data) => {
    setStashedObjects([...stashedObjects, data]);
  };
  const handleDelete = (index) => {
    remove(index);
    // creating a new array to maintain immutability
    const newStashedObjects = [...stashedObjects];
    newStashedObjects.splice(index, 1);
    setStashedObjects(newStashedObjects);
  };
  return (
    <FieldBaseContainer
      label={label}
      layout={layout}
      error={
        formState.isSubmitted && !formState.isSubmitting && error?.message
          ? error
          : undefined
      }
      hasError={formState.isSubmitted && !formState.isSubmitting && !!error}
      wrapper="fieldset"
      name={name}
    >
      {stashedObjects.length > 0 ? (
        <div>
          <Heading size="md">{extra?.label.object.title_added}</Heading>
          {stashedObjects.map((_Object, index) => {
            return (
              <ListObject
                key={`${name}.${index}`}
                index={index}
                name={name}
                extra={extra}
                control={control}
                register={register}
                formState={formState}
                onDelete={handleDelete}
              />
            );
          })}
        </div>
      ) : (
        ''
      )}
      <AddObjects
        name={name}
        register={register}
        control={control}
        fields={fields}
        formState={formState}
        error={error}
        stashedObjects={stashedObjects}
        extra={extra}
        append={append}
        remove={remove}
        onStash={handleStash}
        setValue={setValue}
        getValues={getValues}
        unregister={unregister}
        trigger={trigger}
        clearErrors={clearErrors}
        Field={Field}
      />
    </FieldBaseContainer>
  );
};

export default Multiplicity;

export interface ListObjectProps {
  index: number;
  name: string;
  control: UseFormReturn['control'];
  register: UseFormReturn['register'];
  formState: UseFormReturn['formState'];
  onDelete: (index: number) => void;
  extra?: Record<string, any>;
}

export const ListObject: React.FC<ListObjectProps> = ({
  index,
  name,
  extra,
  control,
  register,
  onDelete,
  formState,
  // onEdit,
}) => {
  const currentName = `${name}.${index}`;
  return (
    <Card variant={extra?.border && 'border'}>
      <CardHeading>
        {extra?.label.object.title} #{index + 1}
      </CardHeading>
      <CardContent>
        <FieldObject
          name={currentName}
          formState={formState}
          register={register}
          control={control}
          {...extra?.of}
        />
      </CardContent>
      <CardAction>
        <Button type="button" variant="link" onClick={() => onDelete(index)}>
          {extra?.label.object.delete}
        </Button>
      </CardAction>
    </Card>
  );
};
