import React, { useState, useEffect } from 'react';
import { getNextStep } from '@digigov/form/Questions/getNextStep';
import { QuestionsContext } from '@digigov/form/Questions/QuestionsContext';
import { StepInterface } from '@digigov/form/Questions/Step/types';
import { QuestionsInterface } from '@digigov/form/Questions/types';

const isBrowser = typeof window !== 'undefined';

/**
 * The Question component accepts question data as props
 * uses composable components to provide a wholesome UX
 *
 */
export const Questions: React.FC<QuestionsInterface> = ({
  name,
  steps,
  initialData = {},
  onChange,
  onSubmit,
  onActiveStep,
  forceStepName,
  localDraft = false,
  children,
}) => {
  const [currentStep, setCurrentStep] = useState<StepInterface>({ name: '' });
  useEffect(() => {
    if (!forceStepName) {
      setCurrentStep(steps[0]);
    }
  }, [forceStepName, steps]);
  useEffect(() => {
    if (forceStepName !== currentStep.name) {
      const forceStep = steps.find(({ name }) => name === forceStepName);
      if (forceStep) setCurrentStep(forceStep);
    }
  }, [forceStepName]);
  const localData =
    isBrowser && localDraft && window.localStorage.getItem(`questions-${name}`);
  const [data, setData] = useState(
    (localData && JSON.parse(localData)) || initialData
  );
  const submitStep = (stepName, stepData): void => {
    data[stepName] = stepData;
    if (localDraft) {
      if (isBrowser)
        window.localStorage.setItem(`questions-${name}`, JSON.stringify(data));
    }
    if (onChange) {
      onChange(data);
    }
    setData(data);
    const nextStep = getNextStep(currentStep, steps, data);
    if (nextStep) {
      if (onActiveStep) onActiveStep(nextStep);
      setCurrentStep(nextStep);
    } else {
      onSubmit(data);
    }
  };

  return (
    <QuestionsContext.Provider
      value={{
        steps,
        currentStep,
        submitStep,
        data,
        onActiveStep,
      }}
    >
      {children}
    </QuestionsContext.Provider>
  );
};
