import React, { useContext } from 'react';
import { QuestionsContext } from '@digigov/form/Questions/QuestionsContext';
import { StepContext } from '@digigov/form/Questions/Step/StepContext';
import { StepTitleBase } from '@digigov/form/Questions/Step/StepTitle';
import {
  SummaryList,
  SummaryListItem,
  SummaryListItemKey,
  SummaryListItemValue,
  SummaryListItemAction,
} from '@digigov/ui/content/SummaryList';
import { Button } from '@digigov/ui/form/Button';
import { useTranslation } from '@digigov/ui/i18n';
import Heading from '@digigov/ui/typography/Heading';

export const ReviewStep = (): React.ReactElement => {
  const { t } = useTranslation();
  const { submitStep, title } = useContext(StepContext);
  const { data, steps, onActiveStep } = useContext(QuestionsContext);
  const filledSteps = steps.filter((step) => !!data[step.name]);
  return (
    <>
      <StepTitleBase title={title || 'Review answers'}></StepTitleBase>
      {filledSteps.map((step) => {
        return (
          <div key={step.name}>
            <Heading size={'md'}>{step.title}</Heading>
            <SummaryList>
              {Object.keys(data[step.name]).map((dataKey) => {
                return (
                  <SummaryListItem key={dataKey}>
                    <SummaryListItemKey>
                      {
                        step.fields.find(({ key }) => key === dataKey).label
                          .primary
                      }
                    </SummaryListItemKey>
                    <SummaryListItemValue>
                      {data[step.name][dataKey]}
                    </SummaryListItemValue>
                    <SummaryListItemAction>
                      <a
                        style={{ cursor: 'pointer' }}
                        onClick={(): void => onActiveStep && onActiveStep(step)}
                      >
                        {t('button.edit')}
                      </a>
                    </SummaryListItemAction>
                  </SummaryListItem>
                );
              })}
            </SummaryList>
          </div>
        );
      })}
      <Button onClick={(): void => submitStep && submitStep()}>
        {t('button.submit')}
      </Button>
    </>
  );
};

export default ReviewStep;
