import React, { useContext, useState } from 'react';
import { QuestionsContext } from '@digigov/form/Questions/QuestionsContext';
import { StepArrayReview } from '@digigov/form/Questions/Step/StepArrayReview';
import { StepContext } from '@digigov/form/Questions/Step/StepContext';
import { StepInterface } from '@digigov/form/Questions/Step/types';

/**
 * The Step component accepts Step data as props
 * uses composable components to provide a wholesome UX
 *
 */
export const Step: React.FC<StepInterface> = (props) => {
  // or return all Questions and currentStepName
  // or return a specific Step object
  const { currentStep, submitStep, data } = useContext(QuestionsContext);

  const [stepData, setStepData] = useState<Record<string, any>[]>([]);
  const [reviewActive, setReviewActive] = useState(false);

  const handleArraySubmit = (_name: string, data: any): void => {
    setStepData([...stepData, data]);
    setReviewActive(true);
  };

  const handleArrayDeleteItem = (deleteIndex: number): void => {
    const nextStepData = stepData.filter((_item, stepIndex) => {
      return stepIndex !== deleteIndex;
    });
    setStepData(nextStepData);
    if (nextStepData.length === 0) {
      setReviewActive(false);
    }
  };

  const handleArrayReviewStep = (data): void => {
    if (data.addMore === 'yes') {
      setReviewActive(false);
    } else if (data.addMore === 'no') {
      submitStep(currentStep.name, stepData);
    }
  };
  if (!currentStep || props.name !== currentStep.name) return null;

  // then provide the currentStep object
  return (
    <StepContext.Provider
      value={{
        ...currentStep,
        submitStep:
          currentStep.type === 'array' ? handleArraySubmit : submitStep,
        initial: data[props.name],
      }}
    >
      {reviewActive ? (
        <StepArrayReview
          array={stepData}
          handleSubmit={handleArrayReviewStep}
          handleDelete={handleArrayDeleteItem}
        />
      ) : (
        props.children
      )}
    </StepContext.Provider>
  );
};

export default Step;
