import React, { useContext } from 'react';
import { Field } from '@digigov/form/Field';
import { Fieldset } from '@digigov/form/Fieldset';
import FormBuilder from '@digigov/form/FormBuilder';
import Label from '@digigov/form/inputs/Label';
import { QuestionsContext } from '@digigov/form/Questions/QuestionsContext';
import { getAddMoreFields } from '@digigov/form/Questions/Step/getAddMoreFields';
import { StepArrayReviewInterface } from '@digigov/form/Questions/Step/types';
import { FieldSpec } from '@digigov/form/types';
import PageTitleContainer, {
  PageTitleHeading,
} from '@digigov/ui/app/PageTitleContainer';
import {
  SummaryList,
  SummaryListItem,
  SummaryListItemKey,
  SummaryListItemValue,
  SummaryListItemAction,
} from '@digigov/ui/content/SummaryList';
import Button from '@digigov/ui/form/Button';
import { useTranslation } from '@digigov/ui/i18n';

export const StepArrayReview: React.FC<StepArrayReviewInterface> = (props) => {
  const { t } = useTranslation();
  const { currentStep } = useContext(QuestionsContext);
  const fields = getAddMoreFields(currentStep);
  const primaryField =
    currentStep.fields.find(
      (field: { key: any }) => field.key === currentStep.review?.primaryFieldKey
    ) || {};
  return (
    <>
      <PageTitleContainer>
        <PageTitleHeading>
          {currentStep.review?.title && t(currentStep.review?.title)}
        </PageTitleHeading>
      </PageTitleContainer>
      <SummaryList>
        {props.array.map(
          (item: Record<string, React.ReactNode>, idx: number) => (
            <SummaryListItem key={idx}>
              <SummaryListItemKey>
                {t(primaryField.label.primary)}
              </SummaryListItemKey>
              <SummaryListItemValue>
                {item[primaryField.key]}
              </SummaryListItemValue>
              <SummaryListItemAction
                onClick={(): void => props.handleDelete(idx)}
              >
                {t('button.delete')}
              </SummaryListItemAction>
            </SummaryListItem>
          )
        )}
      </SummaryList>
      <FormBuilder key="addmore" fields={fields} onSubmit={props.handleSubmit}>
        <Fieldset>
          <Label label={currentStep.review?.addMore.title} />
          {fields.map((field: FieldSpec) => (
            <Field key={field.key} name={field.key} />
          ))}
        </Fieldset>
        <Button type="submit">{t('button.submit')}</Button>
      </FormBuilder>
    </>
  );
};

export default StepArrayReview;
