import React, { useContext } from 'react';
import { StepContext } from '@digigov/form/Questions/Step/StepContext';
import { useTranslation } from '@digigov/ui/i18n';
import Paragraph, { ParagraphProps } from '@digigov/ui/typography/Paragraph';

export interface StepDescriptionInterface extends ParagraphProps {
  description?: string;
}

export const StepDescriptionBase: React.FC<StepDescriptionInterface> = ({
  children,
  description,
  ...props
}) => {
  const { t } = useTranslation();
  return (
    <Paragraph {...props}>
      {children || (description && t(description))}
    </Paragraph>
  );
};

export const StepDescription: React.FC<StepDescriptionInterface> = (props) => {
  const { description: descriptionContext } = useContext(StepContext);
  const description = props.description || descriptionContext;
  return (
    <StepDescriptionBase description={description} {...props}>
      {props.children}
    </StepDescriptionBase>
  );
};

export default StepDescription;
