import React, { useContext } from 'react';
import Field from '@digigov/form/Field';
import { FieldProps } from '@digigov/form/Field/types';
import Fieldset from '@digigov/form/Fieldset';
import FormBuilder from '@digigov/form/FormBuilder';
import { StepContext } from '@digigov/form/Questions/Step/StepContext';
import { FormBuilderProps } from '@digigov/form/types';
import Button from '@digigov/ui/form/Button';
import { useTranslation } from '@digigov/ui/i18n';

export interface StepFormProps {
  submitButton: boolean;
  children: React.ReactNode;
  fields?: FieldProps[];
  initial?: FormBuilderProps['initial'];
}

/**
 * The StepForm component accepts a title, a caption and a
 * decription about the Step asked to the User
 */
export const StepForm: React.FC<StepFormProps> = ({
  children,
  submitButton,
  ...props
}) => {
  const { t } = useTranslation();
  const { name, submitStep, ...rest } = useContext(StepContext);
  const fields = rest.fields.length ? rest.fields : props.fields;
  const initial = rest.initial ? rest.initial : props.initial;
  return (
    <FormBuilder
      initial={initial}
      fields={fields}
      onSubmit={(data): void => {
        submitStep(name, data);
      }}
    >
      {children ? (
        <>
          {children}
          {submitButton && (
            <Button type="submit">{t('button.continue')}</Button>
          )}
        </>
      ) : (
        <>
          <Fieldset>
            {fields.map((field) => (
              <Field key={field.key} name={field.key} />
            ))}
          </Fieldset>
          <Button type="submit">{t('button.continue')}</Button>
        </>
      )}
    </FormBuilder>
  );
};

export default StepForm;
