import React, { useContext } from 'react';
import { StepContext } from '@digigov/form/Questions/Step/StepContext';
import {
  PageTitleContainer,
  PageTitleCaption,
} from '@digigov/ui/app/PageTitleContainer';
import { useTranslation } from '@digigov/ui/i18n';
import { BackLink } from '@digigov/ui/navigation/BackLink';
import { Heading, HeadingProps } from '@digigov/ui/typography/Heading';
import { HeadingCaption } from '@digigov/ui/typography/HeadingCaption';

export interface StepTitleInterface {
  title?: string;
  backButton?: string;
  caption?: string;
  step?: string;
  children?: React.ReactNode;
}

export const StepTitleHeading: React.FC<HeadingProps> = (props) => {
  return <Heading>{props.children}</Heading>;
};

export const StepTitleBase: React.FC<StepTitleInterface> = ({
  caption,
  step,
  title,
  backButton,
  children,
}): React.ReactElement => {
  const { t } = useTranslation();
  return (
    <>
      <BackLink>{backButton || t('button.back')}</BackLink>
      <PageTitleContainer>
        {children || (
          <>
            <HeadingCaption size="xl">{caption && t(caption)}</HeadingCaption>
            {step && <PageTitleCaption>{step}</PageTitleCaption>}
            <StepTitleHeading>{title && t(title)}</StepTitleHeading>
          </>
        )}
      </PageTitleContainer>
    </>
  );
};

/**
 * The StepTitle component accepts a title, a caption and a step indicator
 * about the Step asked to the User
 */
export const StepTitle: React.FC<StepTitleInterface> = (props) => {
  const { caption, title, step, backButton } = useContext(StepContext);
  return (
    <StepTitleBase
      backButton={backButton}
      caption={caption}
      step={step}
      title={title}
    >
      {props.children}
    </StepTitleBase>
  );
};

export default StepTitle;
