import React from 'react';
import { Field } from '@digigov/form';
import Questions, { Step, StepForm, StepTitle } from '@digigov/form/Questions';
import Header from '@digigov/ui/app/Header';
import HeaderContent from '@digigov/ui/app/Header/HeaderContent';
import HeaderSection from '@digigov/ui/app/Header/HeaderSection';
import GovGRFooter from '@digigov/ui/govgr/Footer';
import GovGRLogo from '@digigov/ui/govgr/GovGRLogo';
import BasicLayout, {
  Top,
  Container,
  Main,
  Bottom,
} from '@digigov/ui/layouts/Basic';

const steps = [
  {
    name: 'age',
    title: 'What is your age?',
    backButton: 'Back',
    fields: [
      {
        key: 'age',
        type: 'int',
        required: true,
      },
    ],
    nextStep: (data) => {
      return data.age > 17 ? 'citizen-adult' : 'citizen-underage';
    },
  },
  {
    name: 'citizen-underage',
    title: 'Are you a student?',
    backButton: 'Back',
    fields: [
      {
        key: 'citizen-underage-student',
        type: 'radio',
        required: true,
        options: [
          {
            label: { primary: 'Yes' },
            value: 'yes',
          },
          {
            label: { primary: 'No' },
            value: 'no',
          },
        ],
      },
    ],
  },
  {
    name: 'citizen-adult',
    title: 'Are you currently employed?',
    backButton: 'Back',
    fields: [
      {
        key: 'citizen-adult-employed',
        type: 'radio',
        required: true,
        options: [
          {
            label: { primary: 'Yes' },
            value: 'yes',
          },
          {
            label: { primary: 'No' },
            value: 'no',
          },
        ],
      },
    ],
  },
];

export function Default() {
  return (
    <BasicLayout>
      <Top>
        <Header>
          <HeaderContent>
            <HeaderSection>
              <GovGRLogo href="#" />
            </HeaderSection>
          </HeaderContent>
        </Header>
      </Top>
      <Container>
        <Main>
          <Questions
            name={'example'}
            steps={steps}
            onSubmit={(data) => {
              console.log(data);
            }}
          >
            <Step name="age">
              <StepTitle />
              <StepForm submitButton={true}>
                <Field key="age" name="age" />
              </StepForm>
            </Step>
            <Step name="citizen-underage">
              <StepTitle />
              <StepForm submitButton={true}>
                <Field
                  key="citizen-underage-student"
                  name="citizen-underage-student"
                />
              </StepForm>
            </Step>
            <Step name="citizen-adult">
              <StepTitle backButton="Πίσω" />
              <StepForm submitButton={true}>
                <Field
                  key="citizen-adult-employed"
                  name="citizen-adult-employed"
                />
              </StepForm>
            </Step>
          </Questions>
        </Main>
      </Container>
      <Bottom>
        <GovGRFooter />
      </Bottom>
    </BasicLayout>
  );
}

export default Default;
