import * as React from 'react';
import { render } from '@testing-library/react';

import { Field } from '@digigov/form';
import Questions, {
  Step,
  StepForm,
  StepQuote,
  StepTitle,
} from '@digigov/form/Questions';

const steps = [
  {
    name: 'intro',
    caption: 'intro.caption',
    title: 'intro.title',
    description: 'intro.description',
    fields: [
      {
        key: 'name',
        label: {
          primary: 'name.field.primary',
          secondary: 'name.field.secondary',
        },
        required: true,
        type: 'string',
      },
    ],
  },
  {
    name: 'age',
    caption: 'age.caption',
    title: 'age.title',
    description: 'age.description',
    fields: [
      {
        key: 'dateOfBirth',
        label: {
          primary: 'age.field.primary',
          secondary: 'age.field.secondary',
        },
        required: true,
        type: 'number',
      },
    ],
  },
];

beforeAll(() => {
  global.ResizeObserver = class ResizeObserver {
    observe() {}
    unobserve() {}
    disconnect() {}
  };
});

it('renders the Questions', () => {
  expect(
    render(
      <Questions
        name={'example'}
        onSubmit={(data): void => {
          console.log(data);
        }}
        steps={steps}
      >
        <Step name="intro">
          <StepTitle />
          <StepQuote>This is the intro</StepQuote>
          <StepForm submitButton={true}>
            <Field key={'name'} name="name" />
          </StepForm>
        </Step>
        <Step name="age">
          <StepTitle />
          <StepQuote>This is the age</StepQuote>
          <StepForm submitButton={true}>
            <Field key={'dateOfBirth'} name="dateOfBirth" />
          </StepForm>
        </Step>
      </Questions>
    ).baseElement
  ).toMatchSnapshot();
});
