import React, { useCallback } from 'react';
import { ControlledFieldProps } from '@digigov/form/Field/types';
import { FieldOptionProps } from '@digigov/form/inputs/Label';
import {
  AutoComplete,
  AutoCompleteProps as UIAutoCompleteProps,
} from '@digigov/ui/form/AutoComplete';
import { Hint } from '@digigov/ui/typography/Hint';
import { Base } from '@digigov/ui/utils/Base';
export interface AutoCompleteInputExtra
  extends Omit<
    UIAutoCompleteProps,
    | 'source'
    | 'id'
    | 'templates'
    | 'defaultValue'
    | 'onConfirm'
    | 'dropdownArrow'
  > {
  options: FieldOptionProps[];
}

export interface AutoCompleteInputProps
  extends Omit<ControlledFieldProps, 'value' | 'onChange' | 'extra'> {
  extra: AutoCompleteInputExtra;
  value: string;
  onChange: (v: string | string[] | undefined) => void;
}

export const AutoCompleteInput: React.FC<AutoCompleteInputProps> = ({
  name,
  type,
  extra: { options },
  onChange,
  value,
  ...props
}) => {
  const suggest = useCallback(
    function suggest(
      query: string,
      syncResults: (options: any[]) => void
    ): void {
      syncResults(
        query
          ? options.filter(function (option) {
              return (
                `${option.value} ${option.label?.primary || ''} ${
                  option.label?.secondary || ''
                }`
                  .toLowerCase()
                  .indexOf(query.toLowerCase()) !== -1
              );
            })
          : options
      );
    },
    [options]
  );

  return (
    <AutoComplete
      multiple={type === 'choice:multiple' ? true : false}
      source={suggest}
      onConfirm={(value) => {
        if (Array.isArray(value)) {
          const selectedValues = value.map((item) => item.value);
          if (selectedValues.length > 0) onChange(selectedValues);
          else onChange(undefined);
        } else {
          onChange(value.value);
        }
      }}
      templates={{
        suggestion({ label, value }) {
          return (
            <Base as="div">
              {(label && label.primary && label.primary) || value}
              {label && label.secondary && <Hint>{label.secondary}</Hint>}
            </Base>
          );
        },
        inputValue: (option) => {
          if (!option) {
            return '';
          }
          return option.label.primary || option.value;
        },
      }}
      {...{
        ...props,
        reset: undefined,
        required: undefined,
      }}
      name={name}
      id={`${name}-id`}
      defaultValue={value}
    />
  );
};

export default AutoCompleteInput;
