import React, { useState } from 'react';
import { ControlledFieldProps } from '@digigov/form/Field/types';
import { FieldOptionProps } from '@digigov/form/inputs/Label';
import {
  Checkbox,
  CheckboxItem,
  CheckboxConditional,
} from '@digigov/ui/form/Checkbox';
import { useTranslation } from '@digigov/ui/i18n';
import { Hint } from '@digigov/ui/typography/Hint';

export interface CheckboxesProps
  extends Omit<ControlledFieldProps, 'extra' | 'value'> {
  value?: string[];
  extra: {
    className?: string;
    options: FieldOptionProps[];
  };
  fieldComponent: React.FC<Omit<ControlledFieldProps, 'value' | 'onChange'>>;
}

export const Checkboxes: React.FC<CheckboxesProps> = ({
  name,
  onChange,
  value,
  extra: { options, className },
  disabled,
  Field,
  ...props
}) => {
  if (!value) value = [];
  const handleChange =
    (optionValue, idx, show) =>
    (evt): void => {
      let newValue;
      if (evt.currentTarget.checked) {
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        newValue = value.concat([optionValue]);
      } else {
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore
        newValue = value.filter((val) => val !== optionValue);
      }
      if (show && show.length > 0) {
        setChecked((items) =>
          items.map((item, index) => (index === idx ? !item : item))
        );
      }

      // reset value to undefined instead of an empty array
      // so the error state mechanism can throw validation errors
      if (newValue.length === 0) newValue = undefined;
      onChange(newValue);
    };
  const { t } = useTranslation();
  const [checked, setChecked] = useState(
    Array<boolean>(options.length).fill(false)
  );
  return (
    <Checkbox className={className}>
      {options.map(
        (
          {
            label,
            value: v,
            show,
            disabled: optionDisabled,
            selected,
            ...option
          },
          index
        ) => (
          <React.Fragment key={index}>
            <CheckboxItem
              key={`${name}.${index}`}
              name={`${name}.${v}`}
              value={v}
              disabled={disabled || optionDisabled}
              checked={value?.includes(v)}
              onChange={handleChange(v, index, show)}
              {...option}
              {...{
                ...props,
                reset: undefined,
                defaultValue: undefined,
                onBlur: undefined,
                required: undefined,
                'aria-describedby': undefined,
                type: 'checkbox',
              }}
            >
              {(label && label.primary && t(label.primary)) || value}
              {label && label.secondary && <Hint>{t(label.secondary)}</Hint>}
            </CheckboxItem>

            {!!checked[index] && show && Field && (
              <CheckboxConditional>
                {show.map((fieldName) => (
                  <Field name={fieldName} key={fieldName} />
                ))}
              </CheckboxConditional>
            )}
            {selected && selected()}
          </React.Fragment>
        )
      )}
    </Checkbox>
  );
};

export default Checkboxes;
