import React, { useState } from 'react';
import { UncontrolledFieldProps } from '@digigov/form/Field/types';
import { Button } from '@digigov/ui/form/Button';
import { FileUpload, FileUploadContainer } from '@digigov/ui/form/FileUpload';
import { useTranslation } from '@digigov/ui/i18n';
import { Hint } from '@digigov/ui/typography/Hint';
import { Paragraph } from '@digigov/ui/typography/Paragraph';
export interface FileInputProps extends Omit<UncontrolledFieldProps, 'extra'> {
  extra?: {
    className?: string;
    multiple?: boolean;
    accept?: string;
    limit: {
      maxSize?: number;
    };
  };
}

// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const FileInput: React.FC<any> = React.forwardRef(function FileInput(
  { name, disabled, reset, onChange, ...props },
  ref: any
) {
  const { t } = useTranslation();
  const [files, setFiles] = useState<string[] | undefined>([]);
  const handleChange = (e) => {
    const target = e.target as HTMLInputElement;
    const selectedFiles = Array.from(
      target.files as ArrayLike<{ name: string }>
    ).map(({ name }) => name);
    setFiles(selectedFiles);
    // proceed calling the onChange provided
    // by react-hook-form
    onChange(e);
  };
  return (
    <>
      <FileUploadContainer hasFiles={files && files.length > 0}>
        {files?.length ? (
          <>
            <Paragraph>
              <b>{t('upload.file')}:</b> {`${files.join(', ')}`}
            </Paragraph>
          </>
        ) : (
          <Hint>{t('upload.no_file')}</Hint>
        )}
        <FileUpload
          ref={ref}
          hasFiles={!!files?.length}
          name={name}
          disabled={disabled}
          onChange={handleChange}
          {...{ ...props, required: undefined }}
        >
          {files?.length ? t('upload.change_file') : t('upload.choose_file')}
        </FileUpload>
        {files !== undefined && files.length > 0 && (
          <>
            <Button
              variant="link"
              onClick={(event) => {
                event.preventDefault();
                reset({ [name]: '' });
                setFiles(undefined);
              }}
            >
              {t('upload.reset_file')}
            </Button>
          </>
        )}
      </FileUploadContainer>
    </>
  );
});

export default FileInput;
