import el from '@digigov/form/locales/el';

const INPUTS_INPUT_FIELDS = [
  {
    key: 'location',
    type: 'string',
    label: {
      primary: 'Συμπληρώστε τον τόπο κατοικίας σας',
    },
    required: true,
  },
  {
    key: 'text',
    type: 'text',
    required: true,
    label: {
      primary: 'Συμπληρώστε το αίτημά σας',
    },
  },
  {
    key: 'email',
    type: 'email',
    label: {
      primary: 'Διεύθυνση ηλεκτρονικού ταχυδρομείου (email)',
    },
    required: true,
  },
  {
    key: 'desired-mount',
    type: 'number',
    label: {
      primary: 'Συμπληρώστε το ποσό που σας ενδιαφέρει',
    },
    required: true,
  },
  {
    key: 'age',
    type: 'int',
    required: true,
    label: {
      primary: 'Ποιά είναι η ηλικία σας;',
      secondary: 'Καταχωρίστε την ηλικία σας',
    },
  },
  {
    key: 'afm',
    type: 'afm',
    required: true,
    label: { primary: 'ΑΦΜ' },
  },
  {
    key: 'iban',
    type: 'iban',
    label: {
      primary: 'Συμπληρώστε το αριθμό του τραπεζικού σας λογαριασμού',
    },
    required: true,
  },
  {
    key: 'uuid4',
    type: 'uuid4',
    label: {
      primary: 'Συμπληρώστε το uuid4',
    },
    required: true,
  },
  {
    key: 'mobile-phone',
    type: 'mobile_phone',
    label: {
      primary: 'Συμπληρώστε το κινητό σας τηλέφωνο',
    },
    required: true,
    extra: {
      countries: ['gr'],
      phoneType: 'mobile',
    },
  },
  {
    key: 'phone-number',
    type: 'phone_number',
    label: {
      primary: 'Συμπληρώστε το τηλέφωνό σας',
    },
    required: true,
    extra: {
      countries: ['gr'],
    },
  },
  {
    key: 'phone-number-landline',
    type: 'phone_number',
    label: {
      primary: 'Συμπληρώστε το σταθερό σας τηλέφωνό',
    },
    required: true,
    extra: {
      countries: ['gr'],
      phoneType: 'landline',
    },
  },
  {
    key: 'postal-code',
    type: 'postal_code',
    label: {
      primary: 'Συμπληρώστε τον ταχυδρομικό σας κώδικα',
    },
    extra: { countries: ['GR'] },
    required: true,
  },
];

export const scenarios = [
  {
    title: 'success fill for inputs Input',
    describe: 'inputs Input scenario',
    fields: INPUTS_INPUT_FIELDS,
    fill: [
      {
        fieldKey: 'text',
        value: 'aaaaaaa',
      },
      {
        fieldKey: 'age',
        value: '12',
      },
      {
        fieldKey: 'email',
        value: 'example@mail.com',
      },
      {
        fieldKey: 'location',
        value: 'Location1',
      },
      {
        fieldKey: 'postal-code',
        value: '42100',
      },
      {
        fieldKey: 'afm',
        value: '094536469',
      },
      {
        fieldKey: 'desired-mount',
        value: '12.5',
      },
      {
        fieldKey: 'mobile-phone',
        value: '+306900000000',
      },
      {
        fieldKey: 'phone-number',
        value: '6900000000',
      },
      {
        fieldKey: 'phone-number-landline',
        value: '2100000000',
      },
      {
        fieldKey: 'iban',
        value: 'GR3201122267115323218375195',
      },
      {
        fieldKey: 'uuid4',
        value: '1e805d00-ea67-478a-ab8b-d13ff8b38fa3',
      },
    ],
    expect: [
      {
        type: 'success',
        fieldKey: 'age',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'text',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'email',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'location',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'postal-code',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'afm',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'desired-mount',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'mobile-phone',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'phone-number',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'phone-number-landline',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'iban',
        text: el.form.error.required,
      },
      {
        type: 'success',
        fieldKey: 'uuid4',
        text: el.form.error.required,
      },
    ],
  },
  {
    title: 'empty fill for inputs Input',
    describe: 'inputs Input scenario',
    fields: INPUTS_INPUT_FIELDS,
    fill: [],
    expect: [
      {
        type: 'error',
        fieldKey: 'age',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'email',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'location',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'postal-code',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'afm',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'desired-mount',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'mobile-phone',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'phone-number',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'phone-number-landline',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'iban',
        text: el.form.error.required,
      },
      {
        type: 'error',
        fieldKey: 'uuid4',
        text: el.form.error.required,
      },
    ],
  },
  {
    title: 'incorrect types for inputs Input',
    describe: 'inputs Input scenario',
    fields: INPUTS_INPUT_FIELDS,
    fill: [
      {
        fieldKey: 'age',
        value: 'aa',
      },
      {
        fieldKey: 'email',
        value: '23232',
      },
      {
        fieldKey: 'location',
        value: '23232',
      },
      {
        fieldKey: 'postal-code',
        value: 'aaaaa',
      },
      {
        fieldKey: 'afm',
        value: 'aaaaaaaaa',
      },
      {
        fieldKey: 'desired-mount',
        value: 'aaa',
      },
      {
        fieldKey: 'mobile-phone',
        value: '+33690000000',
      },
      {
        fieldKey: 'phone-number',
        value: '000000000',
      },
      {
        fieldKey: 'phone-number-landline',
        value: '000000000',
      },
      {
        fieldKey: 'iban',
        value: 'aaaaaa',
      },
      {
        fieldKey: 'uuid4',
        value: 'aaaaaa',
      },
    ],
    expect: [
      {
        type: 'error',
        fieldKey: 'age',
        text: el.form.error.number,
      },
      {
        type: 'error',
        fieldKey: 'email',
        text: el.form.error.email,
      },
      {
        type: 'success',
        fieldKey: 'location',
        text: el.form.error.string,
      },
      {
        type: 'error',
        fieldKey: 'postal-code',
        text: el.form.error.postalCode,
      },
      {
        type: 'error',
        fieldKey: 'afm',
        text: el.form.error.afm,
      },
      {
        type: 'error',
        fieldKey: 'desired-mount',
        text: el.form.error.number,
      },
      {
        type: 'error',
        fieldKey: 'mobile-phone',
        text: el.form.error.mobile_phone,
      },
      {
        type: 'error',
        fieldKey: 'phone-number',
        text: el.form.error.phone_number,
      },
      {
        type: 'error',
        fieldKey: 'phone-number-landline',
        text: el.form.error.landline,
      },
      {
        type: 'error',
        fieldKey: 'iban',
        text: el.form.error.iban,
      },
      {
        type: 'error',
        fieldKey: 'uuid4',
        text: el.form.error.uuid4,
      },
    ],
  },
];

export default scenarios;
