import React from 'react';
import { FieldLabelProps } from '@digigov/form/types';
import { LabelTitle } from '@digigov/ui/form/LabelContainer';
import { useTranslation } from '@digigov/ui/i18n';
import { Hint } from '@digigov/ui/typography/Hint';

export interface FieldOptionProps {
  label?: FieldLabelProps;
  value: string;
  show?: string[];
  disabled?: boolean;
  selected?: () => React.ReactNode;
  divider?: string;
}

export interface LabelProps {
  primary?: string;
  secondary?: string;
  className?: string;
  value?: string;
  label?: FieldLabelProps;
}

export const Label: React.FC<LabelProps> = ({ className, label, value }) => {
  const { t } = useTranslation();
  if ((!label || (label && !label.primary && !label.secondary)) && !value) {
    return null;
  }
  return (
    <>
      <LabelTitle className={className} size="sm">
        {(label && label.primary && t(label.primary)) || value}
      </LabelTitle>
      {label && label.secondary && <Hint>{t(label.secondary)}</Hint>}
    </>
  );
};

export default Label;
