import React from 'react';
import FormBuilder, { Field } from '@digigov/form';
import { FieldSpec } from '@digigov/form/types';
import { Button } from '@digigov/ui/form/Button';

const fields: FieldSpec[] = [
  {
    key: 'landline',
    type: 'phone_number',
    label: {
      secondary: 'Εισάγετε το νούμερο του σταθερού σας τηλεφώνου.',
    },
    enabled: false,
    condition: {
      auth_form: {
        is: 'via_mobile_phone',
        then: {
          enabled: true,
          required: true,
        },
      },
    },
  },
  {
    key: 'mobile_phone',
    type: 'mobile_phone',
    label: {
      secondary: 'Εισάγετε το νούμερο του κινητού σας τηλεφώνου.',
    },
    enabled: false,
    condition: {
      auth_form: {
        is: 'via_mobile_phone',
        then: {
          enabled: true,
          required: true,
        },
      },
    },
  },
  {
    key: 'email',
    type: 'email',
    label: {
      secondary: 'Εισάγετε την διεύθυνση του ηλεκτρονικού σας ταχυδρομείου.',
    },
    enabled: false,
    condition: {
      auth_form: {
        is: 'via_email',
        then: {
          enabled: true,
          required: true,
        },
      },
    },
  },
  {
    key: 'auth_form',
    type: 'choice:single',
    required: true,
    label: {
      primary: 'Επιλέξτε μέθοδο πιστοποίησης',
      secondary:
        'Για την ολοκλήρωση της δήλωσης σας, θα χρειαστεί επιπλέον πιστοποίηση. Θα σας στείλουμε ένα κωδικό μιας χρήσης είτε στο τηλέφωνο είτε στην ηλεκτρονική σας διεύθυνση.',
    },
    extra: {
      options: [
        {
          key: 'via_mobile_phone',
          label: { primary: 'Mέσω κινητού τηλεφώνου' },
          value: 'via_mobile_phone',
          show: ['mobile_phone', 'landline'],
        },
        {
          key: 'via_email',
          label: {
            primary: 'Μέσω διεύθυνσης ηλεκτρονικού ταχυδρομείου (e-mail)',
          },
          value: 'via_email',
          show: ['email'],
        },
      ],
    },
  },
];

export const Conditional = () => (
  <FormBuilder
    onSubmit={(data) => {
      console.log(data);
    }}
    fields={fields}
  >
    <Field key="auth_form" name="auth_form" />
    <Button type="submit">Συνέχεια</Button>
  </FormBuilder>
);

export default Conditional;
