import React from 'react';
import { useWatch } from 'react-hook-form';
import { UncontrolledFieldProps } from '@digigov/form/Field/types';
import { FieldOptionProps } from '@digigov/form/inputs/Label';
import {
  RadioContainer,
  RadioItem,
  RadioConditional,
} from '@digigov/ui/form/RadioContainer';
import { useTranslation } from '@digigov/ui/i18n';
import { Hint } from '@digigov/ui/typography/Hint';
import { Base } from '@digigov/ui/utils/Base';

export interface RadioButtonsGroupProps
  extends Omit<UncontrolledFieldProps, 'extra'> {
  extra: {
    className?: string;
    options: FieldOptionProps[];
    dense?: boolean;
  };
  fieldComponent?: React.FC<Omit<UncontrolledFieldProps, 'register'>>;
}

export const RadioButtonsGroup: React.FC<RadioButtonsGroupProps> = ({
  name,
  control,
  register,
  extra: { options, className },
  disabled,
  Field,
  ...props
}) => {
  const currentValue: string | undefined = useWatch({ control, name });
  const { t } = useTranslation();
  return (
    <RadioContainer className={className} id={name}>
      {options.map(
        ({
          label,
          value: v,
          show,
          disabled: optionDisabled,
          selected,
          ...option
        }) => (
          <Base as="div" key={`${name}.${v}`}>
            <RadioItem
              {...register(name)}
              id={`${name}.${v}`}
              value={v}
              disabled={disabled || optionDisabled}
              {...option}
              {...{
                ...props,
                reset: undefined,
                required: undefined,
                error: undefined,
                'aria-describedby': undefined,
                type: 'radio',
              }}
            >
              {label && label.primary && (
                <Base as="span">{t(label.primary) || v}</Base>
              )}
              {label && label.secondary && <Hint>{t(label.secondary)}</Hint>}
            </RadioItem>
            {selected && selected()}
            {currentValue === v && show && Field && (
              <RadioConditional>
                {show.map((fieldName) => (
                  <Field name={fieldName} key={fieldName} />
                ))}
              </RadioConditional>
            )}
          </Base>
        )
      )}
    </RadioContainer>
  );
};
export const ControlledRadioButtonsGroup: React.FC<
  RadioButtonsGroupProps & { onChange: (e: any) => void; value: any }
> = ({
  name,
  extra: { options, className },
  disabled,
  onChange,
  value,
  Field,
  ...props
}) => {
  const currentValue: string | undefined = value;
  const { t } = useTranslation();
  return (
    <RadioContainer className={className} id={name}>
      {options.map(
        ({
          label,
          value: v,
          show,
          disabled: optionDisabled,
          selected,
          ...option
        }) => (
          <React.Fragment key={`${name}.${v}`}>
            <RadioItem
              onChange={(e) => {
                console.log(e);
                onChange(e);
              }}
              id={`${name}.${v}`}
              value={v}
              checked={currentValue === v}
              disabled={disabled || optionDisabled}
              {...option}
              {...{
                ...props,
                reset: undefined,
                required: undefined,
                error: undefined,
                'aria-describedby': undefined,
                type: 'radio',
              }}
            >
              {(label && label.primary && t(label.primary)) || v}
              {label && label.secondary && <Hint>{t(label.secondary)}</Hint>}
            </RadioItem>
            {selected && selected()}
            {currentValue === v && show && (
              <RadioConditional>
                {show.map((fieldName) => (
                  <Field name={fieldName} key={fieldName} />
                ))}
              </RadioConditional>
            )}
          </React.Fragment>
        )
      )}
    </RadioContainer>
  );
};

export default RadioButtonsGroup;
