import React from 'react';
import { UncontrolledFieldProps } from '@digigov/form/Field/types';
import { FieldOptionProps } from '@digigov/form/inputs/Label';
import {
  SelectContainer,
  SelectOption,
} from '@digigov/ui/form/SelectContainer';

export interface SelectProps extends Omit<UncontrolledFieldProps, 'extra'> {
  extra: {
    className?: string;
    options: FieldOptionProps[];
  };
}

export const Select: React.ExoticComponent<SelectProps> = React.forwardRef(
  function WrappedSelect(
    { name, extra: { options, className }, disabled, ...props },
    ref: never
  ) {
    return (
      <SelectContainer
        className={className}
        ref={ref}
        name={name}
        disabled={disabled}
        {...{ ...props, reset: undefined, required: undefined }}
      >
        {options.map(({ value, label }) => (
          <SelectOption key={value} value={value}>
            {label && label.primary ? label.primary : value}
          </SelectOption>
        ))}
      </SelectContainer>
    );
  }
);

export default Select;
