import { UseFormReturn, UseFormProps } from 'react-hook-form';
import {
  FieldComponentRegistry,
  FieldLabelProps,
  FieldSpec,
  FormData,
} from '@digigov/form/Field/types';
import { ValidatorSchema } from '@digigov/form/validators/types';
export * from '@digigov/form/Field/types';
export interface FieldError {
  message: string;
}

export interface FieldsetSpec {
  key: string;
  fields: string[];
  label?: FieldLabelProps;
  body?: React.ReactNode;
}

export interface FormContextProps {
  fieldsetsMap?: Record<string, FieldsetSpec>;
  fieldsMap: Record<string, FieldSpec>;
  control: UseFormReturn['control'];
  register: UseFormReturn['register'];
  trigger: UseFormReturn['trigger'];
  clearErrors: UseFormReturn['clearErrors'];
  watch: UseFormReturn['watch'];
  getFieldState: UseFormReturn['getFieldState'];
  setValue: UseFormReturn['setValue'];
  getValues: UseFormReturn['getValues'];
  unregister: UseFormReturn['unregister'];
  formState: UseFormReturn['formState'];
  reset: UseFormReturn['reset'];
  resetField: UseFormReturn['resetField'];
  registerField: (field: FieldSpec) => void;
  errors: UseFormReturn['formState']['errors'];
  componentRegistry?: FieldComponentRegistry;
  submit: () => Promise<void>;
}

export interface FormBuilderProps {
  fields?: FieldSpec[];
  fieldsets?: FieldsetSpec[];
  initial?: FormData;
  onSubmit?: (data: FormData) => void | null | FieldError[];
  mode?: UseFormProps['mode'];
  reValidateMode?: UseFormProps['reValidateMode'];
  criteriaMode?: UseFormProps['criteriaMode'];
  children?: React.ReactNode;
  shouldFocusError?: boolean;
  auto?: boolean;
  validatorRegistry?: Record<string, ValidatorSchema[]>;
  componentRegistry?: FieldComponentRegistry;
  grid?: boolean;
  controlledFieldsOnly?: boolean;
}

export interface FormBaseProps
  extends Omit<FormBuilderProps, 'fields' | 'fieldsets' | 'auto'> {
  fieldsetsMap?: Record<string, FieldsetSpec>;
  fieldsMap: Record<string, FieldSpec>;
  registerField: (field: FieldSpec) => void;
  resolver: any;
}
