export function validateAFM(afm: string): boolean {
  if (afm.length !== 9) {
    // "afm should be 9 digits"
    return false;
  }

  if (!/^\d+$/.test(afm)) {
    // "This is not a number"
    return false;
  }

  if (afm === '0'.repeat(9)) {
    // "This is zero number (000000000)"
    return false;
  }

  const sum = afm
    .substring(0, 8)
    .split('')
    .reduce((s, v, i) => s + (parseInt(v) << (8 - i)), 0);

  const calc = sum % 11;
  const d9 = parseInt(afm[8]);
  const valid = calc % 10 === d9;
  return valid;
}

export const AFM_VALIDATOR = {
  name: 'afm-validator',
  message: 'form.error.afm',
  test: (value): boolean => {
    if (value) {
      return validateAFM(value);
    }
    return true;
  },
};
