import { FieldSpec } from '@digigov/form/types';
import { ValidatorSchema } from '@digigov/form/validators/types';

const DEFAULT_FILE_MAX_SIZE = 10000000;

export const FILE_MAX_SIZE_VALIDATOR = (field: FieldSpec): ValidatorSchema => ({
  name: 'file-max-size-validator',
  message: {
    key:
      field.type === 'file' ? 'form.error.file_size' : 'form.error.image_size',
    context: {
      maxSizeToMb:
        (field?.extra?.limit.maxSize || DEFAULT_FILE_MAX_SIZE) / 1000000,
    },
  },
  test: (value: File[]): boolean => {
    if (value) {
      for (const file of value) {
        const maxSize = field?.extra?.limit?.maxSize || DEFAULT_FILE_MAX_SIZE;
        if (file.size > maxSize) {
          return false;
        }
      }
    }
    return true;
  },
});
