import { FieldSpec } from '@digigov/form/types';
import { ValidatorSchema } from '@digigov/form/validators/types';
export function validateIban(value: string, countryCode: string): boolean {
  value = value.replace(/\s/g, '').replace(/-/g, '');
  if (value.match(/^[0-9]*$/i)) {
    // this is for greek iban without the country code
    if (value.length !== 25) {
      return false;
    }
  } else {
    value = value.toUpperCase();
    if (countryCode) {
      if (!value.startsWith(countryCode.toUpperCase())) {
        return false;
      }
      if (value.length === ibanCountryCodesLengths[countryCode.toUpperCase()]) {
        return true;
      }
    }
    if (value.length !== 27) {
      // this is for greek iban
      return false;
    }
  }
  return true;
}

export const IBAN_VALIDATOR = (field: FieldSpec): ValidatorSchema => {
  const countryCode = field?.extra?.country;
  return {
    name: 'iban-validator',
    message: 'form.error.iban',
    test: (value: string): boolean => {
      if (!value) {
        return true;
      }
      return validateIban(value, countryCode);
    },
  };
};

const ibanCountryCodesLengths = {
  AD: 24,
  AT: 20,
  AZ: 28,
  BH: 22,
  BY: 28,
  BE: 16,
  BA: 20,
  BR: 29,
  BG: 22,
  CR: 22,
  HR: 21,
  CY: 28,
  CZ: 24,
  DK: 18,
  DO: 28,
  EG: 29,
  SV: 28,
  EE: 20,
  FO: 18,
  FI: 18,
  FR: 27,
  GE: 22,
  DE: 22,
  GI: 23,
  GR: 27,
  GL: 18,
  GT: 28,
  VA: 22,
  HU: 28,
  IS: 26,
  IQ: 23,
  IE: 22,
  IL: 23,
  IT: 27,
  JO: 30,
  KZ: 20,
  XK: 20,
  KW: 30,
  LV: 21,
  LB: 28,
  LI: 21,
  LT: 20,
  LU: 20,
  MT: 31,
  MR: 27,
  MU: 30,
  MD: 24,
  MC: 27,
  ME: 22,
  NL: 18,
  MK: 19,
  NO: 15,
  PK: 24,
  PS: 29,
  PL: 28,
  PT: 25,
  QA: 29,
  RO: 24,
  LC: 32,
  SM: 27,
  ST: 25,
  SA: 24,
  RS: 22,
  SC: 31,
  SK: 24,
  SI: 19,
  ES: 24,
  SE: 24,
  CH: 21,
  TL: 23,
  TN: 24,
  TR: 26,
  UA: 29,
  AE: 23,
  GB: 22,
  VG: 24,
};
