import * as yup from 'yup';
import { FieldSpec } from '@digigov/form/types';
import { ValidatorSchema } from '@digigov/form/validators/types';

export * from '@digigov/form/validators/utils/afm';
export * from '@digigov/form/validators/utils/file';
export * from '@digigov/form/validators/utils/iban';
export * from '@digigov/form/validators/utils/otp';
export * from '@digigov/form/validators/utils/image';
export * from '@digigov/form/validators/utils/phone';
export * from '@digigov/form/validators/utils/postal_code';
export * from '@digigov/form/validators/utils/uuid4';
export * from '@digigov/form/validators/utils/text_limit';
export * from '@digigov/form/validators/utils/date';

export function getYupField(field: FieldSpec, yupTypeMap: Record<string, any>) {
  const yupField = yupTypeMap[field?.type || 'string'] || yupTypeMap['string'];
  return yupField(field);
}
export function computeShape(
  fields: FieldSpec[],
  yupTypeMap: Record<string, ValidatorSchema>,
  validatorRegistry: Record<string, ValidatorSchema[]> | undefined
) {
  const fieldSchemas = {};
  const objectFields: Record<string, FieldSpec[]> = {};
  fields.forEach((field) => {
    let yupField = getYupField(field, yupTypeMap);
    if (field.condition) {
      for (const key in field.condition) {
        let then: any, otherwise: any;
        if (field.condition[key].then) {
          if (field.condition[key].then?.required === false) {
            then = yupField.nullable();
          } else if (field.condition[key].then?.required === true) {
            then = yupField.nullable().required('form.error.required');
          }
        }
        if (field.condition[key].else) {
          if (field.condition[key].else?.required === false) {
            otherwise = yupField.nullable();
          } else if (field.condition[key].else?.required === true) {
            otherwise = yupField.nullable().required('form.error.required');
          }
        }
        if (then || otherwise) {
          yupField = yupField.when(key, {
            is: (val) => {
              //@ts-ignore
              const is = field.condition[key].is;
              if (is === val || (Array.isArray(val) && val.includes(is))) {
                return true;
              } else {
                return false;
              }
            },
            then,
            otherwise,
          });
        }
      }
    } else if (field.required) {
      yupField = yupField.nullable().required('form.error.required');
    }
    if (validatorRegistry && field.type && validatorRegistry[field.type]) {
      validatorRegistry[field.type].forEach((validator: any) => {
        yupField = yupField.test(validator);
      });
    }
    if (field.validators) {
      field.validators.forEach((validator) => {
        yupField = yupField.test(validator);
      });
    }
    fieldSchemas[field.key] = yupField;
  });
  for (const objectKey in objectFields) {
    fieldSchemas[objectKey] = getYupObjectShape(
      objectFields[objectKey],
      yupTypeMap,
      validatorRegistry
    );
  }
  return fieldSchemas;
}

export function getYupObjectShape(
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  fields: FieldSpec[] | any,
  yupTypeMap: Record<string, any>,
  validatorRegistry?: Record<string, ValidatorSchema[]>
) {
  if (!fields.current) {
    const fieldSchemas = computeShape(fields, yupTypeMap, validatorRegistry);
    return yup.object().shape(fieldSchemas);
  }

  return yup.lazy(function () {
    const fieldSchemas = computeShape(
      Object.values(fields.current),
      yupTypeMap,
      validatorRegistry
    );
    return yup.object().shape(fieldSchemas);
  });
}
