import { FieldSpec } from '@digigov/form/types';
import { ValidatorSchema } from '@digigov/form/validators/types';

const CODE_REGEX = /^[12345678][0-9]{4}$/;
export function validatePostalCode(
  number: string,
  countries: string[]
): boolean {
  if (!countries) {
    return false;
  } else {
    if (countries.length === 1 && countries[0].toUpperCase() === 'GR') {
      // Greek postal code must be 5 digits long and shouldn't start with 0 or 9.
      return CODE_REGEX.test(number);
    } else {
      return true;
    }
  }
}

export const POSTALCODE_VALIDATOR = (field: FieldSpec): ValidatorSchema => {
  const countryCode = field?.extra?.countries;
  return {
    name: 'postal-code-validator',
    message: 'form.error.postalCode',
    test: (value: string): boolean => {
      if (!value) {
        return true;
      }
      return validatePostalCode(value, countryCode);
    },
  };
};
