import { FieldSpec } from '@digigov/form/types';
import { ValidatorSchema } from '@digigov/form/validators/types';

export function validateText(value: string, min: number, max: number): boolean {
  let validator;
  if (min || max) {
    if (value.length < min || value.length > max) {
      return (validator = false);
    } else {
      return (validator = true);
    }
  }
  return validator;
}

export const TEXT_LIMIT_VALIDATOR = (field: FieldSpec): ValidatorSchema => {
  const min: number = field?.extra?.limit?.min;
  const max: number = field?.extra?.limit?.max;
  return {
    name: 'text-limit-validator',
    message: (v: any): any => {
      if (min || max) {
        if (v.value.length < min) {
          return {
            key: 'form.error.text.less_than',
            context: { min: field?.extra?.limit?.min },
          };
        }
        if (v.value.length > max) {
          return {
            key: 'form.error.text.more_than',
            context: { max: field?.extra?.limit?.max },
          };
        }
      }
    },
    test: (value: string): boolean => {
      if (!value) {
        return true;
      }
      return validateText(value, min as number, max as number);
    },
  };
};
