import {
  validateUUID4,
  validateIban,
  validatePostalCode,
  validatePhoneNumber,
} from '@digigov/form/validators/utils';

it('validates wrong uuid4 for empty value', () => {
  expect(validateUUID4('')).toBe(false);
});

it('validates wrong uuid4 because of length', () => {
  expect(validateUUID4('9e463bc44a294bab8ee23af6cc3cbbe3')).toBe(false);
});

it('validates wrong uuid4 with correct length and wrong form', () => {
  expect(validateUUID4('ab123cd1-1234-ad34-ad45-12345abcdefg')).toBe(false);
});

it('validates correct uuid4 validator', () => {
  expect(validateUUID4('9e463bc4-4a29-4bab-8ee2-3af6cc3cbbe3')).toBe(true);
});

it('validates correct gr iban', () => {
  expect(validateIban('GR7801100800000008009825202', 'GR')).toBe(true);
});

it('validates correct iban with spaces and dashes', () => {
  expect(validateIban('GR 7801-1008 0000-0008 0098-25202', 'GR')).toBe(true);
});

it('validates correct foreign iban', () => {
  expect(validateIban('DE75512108001245126199', 'DE')).toBe(true);
});

it('validates wrong iban for empty value', () => {
  expect(validateIban('', '')).toBe(false);
});

it('validates wrong greek iban for wrong length', () => {
  expect(validateIban('GR78011008000000080098252020', 'gr')).toBe(false);
});

it('validates wrong iban for non existing country code', () => {
  expect(validateIban('AAA78011008000000080098252020', 'aaa')).toBe(false);
});

it('validates correct greek iban whithout country code', () => {
  expect(validateIban('7801100800000008009825202', '')).toBe(true);
});

it('validates wrong postal code without country code', () => {
  expect(validatePostalCode('123', [])).toBe(true);
});

it('validates wrong postal code with wrong country code', () => {
  expect(validatePostalCode('123', ['FR'])).toBe(true);
});

it('validates wrong postal code with greek country code', () => {
  expect(validatePostalCode('123', ['GR'])).toBe(false);
});

it('validates postal code with greek country code', () => {
  expect(validatePostalCode('11143', ['GR'])).toBe(true);
});

it('validates phone number type landline with greek country code', () => {
  expect(validatePhoneNumber('2102934896', ['GR'], 'landline')).toBe(true);
});

it('throws if given country is not supported', () => {
  expect(() => validatePhoneNumber('2102934896', ['CH'], 'landline')).toThrow(
    'Country CH is not supported'
  );
});

it('validates phone number type mobile with gr country code', () => {
  expect(validatePhoneNumber('6934100982', ['GR'], 'mobile')).toBe(true);
});

it('validates phone number with no type and gr country code', () => {
  expect(validatePhoneNumber('6934100982', ['gr'], null)).toBe(true);
});

it('validates invalid phone number with no type and gr country code', () => {
  expect(validatePhoneNumber('41446681800', ['gr'], null)).toBe(false);
});
